![CI](https://github.com/ComputationalPhysiology/mps_motion/workflows/CI/badge.svg)
[![Github Pages](https://github.com/ComputationalPhysiology/mps_motion/actions/workflows/build_docs.yml/badge.svg)](https://github.com/ComputationalPhysiology/mps_motion/actions/workflows/build_docs.yml)
[![PyPI version](https://badge.fury.io/py/mps-motion.svg)](https://badge.fury.io/py/mps-motion)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![codecov](https://codecov.io/gh/ComputationalPhysiology/mps_motion/branch/main/graph/badge.svg?token=8DQFJGH4E7)](https://codecov.io/gh/ComputationalPhysiology/mps_motion)

# MPS Motion

Library for tracking motion in cardiac mps data


* Source code: https://github.com/ComputationalPhysiology/mps_motion
* Documentation: https://computationalphysiology.github.io/mps_motion


## Installation

See: https://computationalphysiology.github.io/mps_motion/install.html


## Getting started

See https://computationalphysiology.github.io/mps_motion/quickstart.html


## Authors

- Henrik Finsberg henriknf@simula.no

## License
MIT
